@@ -28,7 +28,7 @@ int BayesSUR_internal(const std::string& dataFile, const std::string& mrfGFile,
                     const std::string& gammaInit = "MLE",
                     const std::string& betaPrior="independent",
                     bool output_gamma = true, bool output_beta = true, bool output_G = true, bool output_sigmaRho = true, 
-                    bool output_pi = true, bool output_tail = true, bool output_model_size = true, bool output_CPO = true )
+                    bool output_pi = true, bool output_tail = true, bool output_model_size = true, bool output_CPO = true, bool output_model_visit = false )
 {
   int status {1};
   
@@ -36,7 +36,7 @@ int BayesSUR_internal(const std::string& dataFile, const std::string& mrfGFile,
   {
     status =  drive(dataFile,mrfGFile,blockFile,structureGraphFile,hyperParFile,outFilePath,nIter,burnin,nChains,
                     covariancePrior,gammaPrior,gammaSampler,gammaInit,betaPrior, output_gamma, output_beta,
-                    output_G, output_sigmaRho, output_pi, output_tail, output_model_size, output_CPO);
+                    output_G, output_sigmaRho, output_pi, output_tail, output_model_size, output_CPO, output_model_visit);
   }
   catch(const std::exception& e)
   {
